@@ -61,7 +61,6 @@ def close_all_local_instances(port_range=None):
             close_mapdl(port)
 
 
-# TODO: Will remove this as this should no longer be used
 def check_ports(port_range, ip='localhost'):
     """Check the state of ports in a port range"""
     ports = {}
@@ -91,7 +90,7 @@ def port_in_use(port, host=LOCALHOST):
 def launch_grpc(exec_file='', jobname='file', nproc=2, ram=None,
                 run_location=None, port=MAPDL_DEFAULT_PORT,
                 additional_switches='', custom_bin=None,
-                override=True, timeout=10) -> int:
+                override=True, timeout=20, verbose=False) -> int:
     """Start MAPDL locally in gRPC mode.
 
     Parameters
@@ -136,6 +135,11 @@ def launch_grpc(exec_file='', jobname='file', nproc=2, ram=None,
         Useful when a prior MAPDL session has exited prematurely and
         the lock file has not been deleted.
 
+    verbose : bool, optional
+        Print all output when launching and running MAPDL.  Not
+        recommended unless debugging the MAPDL start.  Default
+        ``False``.
+
     Returns
     -------
     port : int
@@ -277,13 +281,22 @@ def launch_grpc(exec_file='', jobname='file', nproc=2, ram=None,
     port_sw = '-port %d' % port
     grpc_sw = '-grpc'
 
+    # remove any temporary error files at the run location.  This is
+    # important because we need to know if MAPDL is already running
+    # here and because we're looking for any temporary files that are
+    # created to tell when the process has started
+    for filename in os.listdir(run_location):
+        if ".err" == filename[-4:] and jobname in filename:
+            try:
+                os.remove(filename)
+            except:
+                raise IOError('Unable to remove {filename}.  There might be '
+                              'an instance of MAPDL running at this location')
+
     # Windows will spawn a new window, only linux will let you use pexpect...
     if os.name == 'nt':
 
-        # # track PIDs since MAPDL isn't directly launched within the shell
-        # import psutil
-        # orig_pids = psutil.pids()
-
+        # track PIDs since MAPDL isn't directly launched within the shell
         tmp_inp = '.__tmp__.inp'
         with open(os.path.join(run_location, tmp_inp), 'w') as f:
             f.write('FINISH\r\n')
@@ -294,63 +307,36 @@ def launch_grpc(exec_file='', jobname='file', nproc=2, ram=None,
                    additional_switches, port_sw, grpc_sw]
         command = ' '.join(command)
 
-        subprocess.Popen(command, shell=False, cwd=run_location,
-                         stdin=subprocess.DEVNULL,
-                         stdout=subprocess.DEVNULL,
-                         stderr=subprocess.DEVNULL)
-
-        # watch for the creation of temporary files at the run_directory
-        for _ in range(100):
-            # check if any error files have been created.  This is
-            # more reliable than using the lock file
-
-            files = os.listdir(run_location)
-            has_ans = any([filename for filename in files if ".err" in filename])
-            if has_ans:
-                break
-            time.sleep(0.1)
-
-    else:
-        # use pexpect on linux for better error reporting
-        import pexpect
-        from pexpect import popen_spawn
-
+    else:  # linux
         command = ' '.join(['"%s"' % exec_file, job_sw, cpu_sw,
                             ram_sw, additional_switches, port_sw,
                             grpc_sw])
 
-        process = popen_spawn.PopenSpawn(command,
-                                         timeout=timeout,
-                                         cwd=run_location)
+    if verbose:
+        subprocess.Popen(command,
+                         shell=os.name != 'nt',
+                         cwd=run_location)
+    else:
+        subprocess.Popen(command,
+                         shell=os.name != 'nt',
+                         cwd=run_location,
+                         stdin=subprocess.DEVNULL,
+                         stdout=subprocess.DEVNULL,
+                         stderr=subprocess.DEVNULL)
 
-        try:
-            idx = process.expect(['Server listening',
-                                  'Another ANSYS job with the same job name',
-                                  'PRESS <CR> OR <ENTER> TO CONTINUE',
-                                  'Address already in use',
-                                  'ERROR'])
 
-            if idx == 1:
-                raise LockFileException()
+    # watch for the creation of temporary files at the run_directory.
+    # This lets us know that the MAPDL process has at least started
+    sleep_time = 0.1
+    for _ in range(int(timeout/sleep_time)):
+        # check if any error files have been created.  This is
+        # more reliable than using the lock file
 
-            if idx == 2:
-                process.sendline('')  # enter to continue
-                process.expect('Server listening', timeout=1)
-            elif idx == 3:
-                raise RuntimeError('Failed to start MAPDL gRPC at port %d.  ' % port
-                                   + 'Port appears to be already in use.  Please '
-                                   'specify a different port with the ``port`` '
-                                   'argument.')
-            elif idx > 3:  # catch all
-                msg = process.read().decode()
-                raise RuntimeError('Failed to start local MAPDL instance:\n"%s"'
-                                   % msg)
-        except pexpect.EOF:
-            msg = process.read().decode()
-            raise RuntimeError('Failed to start local MAPDL instance:\n"%s"' % msg)
-        except pexpect.TIMEOUT:
-            msg = process.before.decode()
-            raise RuntimeError('Failed to start local MAPDL instance:\n"%s"' % msg)
+        files = os.listdir(run_location)
+        has_ans = any([filename for filename in files if ".err" in filename])
+        if has_ans:
+            break
+        time.sleep(sleep_time)
 
     return port, run_location
 
@@ -575,7 +561,8 @@ def launch_mapdl(exec_file=None, run_location=None, jobname='file',
                  start_timeout=120, port=None,
                  custom_bin=None, cleanup_on_exit=True,
                  start_instance=True, ip=LOCALHOST,
-                 clear_on_connect=True, log_apdl=False, **kwargs):
+                 clear_on_connect=True, log_apdl=False,
+                 verbose_mapdl=False, **kwargs):
     """Start MAPDL locally in gRPC mode.
 
     Parameters
@@ -609,7 +596,7 @@ def launch_mapdl(exec_file=None, run_location=None, jobname='file',
         provides the best performance and stability.  The ``'corba'``
         mode is available from v17.0 and newer and is given legacy
         support.  This mode requires the additional
-        ``ansys-mapdl-corba`` module.  Finally, the ``'console'`` mode
+        ``ansys_corba`` module.  Finally, the ``'console'`` mode
         is for legacy use only Linux only prior to v17.0.  This console
         mode is pending depreciation.
 
@@ -674,6 +661,11 @@ def launch_mapdl(exec_file=None, run_location=None, jobname='file',
     remove_temp_files : bool, optional
         Removes temporary files on exit.  Default ``False``.
 
+    verbose_mapdl : bool, optional
+        Enable printing of all output when launching and running
+        MAPDL.  This should be used for debugging only as output can
+        be tracked within pymapdl.  Default ``False``.
+
     Examples
     --------
     Launch MAPDL using the best protocol.
@@ -863,20 +855,24 @@ def launch_mapdl(exec_file=None, run_location=None, jobname='file',
 
     if mode == 'console':
         from ansys.mapdl.core.mapdl_console import MapdlConsole
-        mapdl = MapdlConsole(loglevel=loglevel, log_apdl=log_apdl, **start_parm)
+        mapdl = MapdlConsole(loglevel=loglevel, log_apdl=log_apdl,
+                             **start_parm)
     elif mode == 'corba':
         try:
             # pending deprication to ansys-mapdl-corba
             from ansys.mapdl.core.mapdl_corba import MapdlCorba
         except ImportError:
-            raise ImportError('To use this feature, install ansys.mapdl.corba with\n\n'
-                              '    pip install ansys-mapdl-corba')
+            raise ImportError('To use this feature, install the MAPDL CORBA package'
+                              ' with:\n\n'
+                              '    pip install ansys_corba')
 
         broadcast = kwargs.get('log_broadcast', False)
         mapdl = MapdlCorba(loglevel=loglevel, log_apdl=log_apdl,
-                           log_broadcast=broadcast, **start_parm)
+                           log_broadcast=broadcast, verbose=verbose_mapdl,
+                           **start_parm)
     elif mode == 'grpc':
-        port, actual_run_location = launch_grpc(port=port, **start_parm)
+        port, actual_run_location = launch_grpc(port=port, verbose=verbose_mapdl,
+                                                **start_parm)
         mapdl = MapdlGrpc(ip=LOCALHOST, port=port,
                           cleanup_on_exit=cleanup_on_exit,
                           loglevel=loglevel, set_no_abort=set_no_abort,
