@@ -11,16 +11,11 @@ import weakref
 import warnings
 
 import numpy as np
-import pyvista as pv
-import scooby
-
-from ansys.mapdl.reader import Archive
 
 from ansys.mapdl import core as pymapdl
 from ansys.mapdl.core.mapdl_functions import _MapdlCommands
 from ansys.mapdl.core.misc import (random_string, supress_logging,
                                    run_as_prep7, last_created)
-from ansys.mapdl.core.geometry_commands import geometry_commands
 from ansys.mapdl.core.element_commands import element_commands
 from ansys.mapdl.core.errors import MapdlRuntimeError, MapdlInvalidRoutineError
 from ansys.mapdl.core.plotting import general_plotter
@@ -31,17 +26,6 @@ _PERMITTED_ERRORS = [
     r'(\*\*\* ERROR \*\*\*).*[\r\n]+.*is turning inside out.',
 ]
 
-
-MATPLOTLIB_LOADED = True
-try:
-    import matplotlib
-    if os.name == 'nt':
-        matplotlib.use('tkagg')  # for windows
-    import matplotlib.pyplot as plt
-    import matplotlib.image as mpimg
-except:  # pragma: no cover
-    MATPLOTLIB_LOADED = False
-
 # test for png file
 PNG_TEST = re.compile('WRITTEN TO FILE(.*).png')
 
@@ -375,6 +359,9 @@ class _MapdlCore(_MapdlCommands):
     def _mesh(self):
         """Write entire archive to ASCII and read it in as an
         ``ansys.mapdl.core.Archive``"""
+        # lazy import here to avoid loading pyvista and vtk
+        from ansys.mapdl.reader import Archive
+
         if self._archive_cache is None:
             # write database to an archive file
             arch_filename = os.path.join(self.directory, '_tmp.cdb')
@@ -597,6 +584,9 @@ class _MapdlCore(_MapdlCommands):
         Only selected nodes [NSEL] are displayed.  Elements need not
         be defined.
         """
+        # lazy import here to avoid top level import
+        import pyvista as pv
+
         if vtk is None:
             vtk = self._use_vtk
 
@@ -620,7 +610,6 @@ class _MapdlCore(_MapdlCommands):
         if isinstance(knum, bool):
             knum = int(knum)
 
-        self._enable_interactive_plotting()
         return super().nplot(knum)
 
     def vplot(self, nv1="", nv2="", ninc="", degen="", scale="",
@@ -774,10 +763,10 @@ class _MapdlCore(_MapdlCommands):
                 meshes.append({'mesh': surf})
 
             if show_area_numbering:
-                anums = np.unique(surf['area_num'])
+                anums = np.unique(surf['entity_num'])
                 centers = []
                 for anum in anums:
-                    area = surf.extract_cells(surf['area_num'] == anum)
+                    area = surf.extract_cells(surf['entity_num'] == anum)
                     centers.append(area.center)
 
                 labels.append({'points': np.array(centers), 'labels': anums})
@@ -816,15 +805,23 @@ class _MapdlCore(_MapdlCommands):
             Increasing the resolution produces a "sharper" image but
             takes longer to render.
         """
-        if MATPLOTLIB_LOADED:
-            if not self._png_mode:
-                self.show('PNG')
-                self.gfile(pixel_res)
-        else:
+        if not self._has_matplotlib:
             raise ImportError('Install matplotlib to display plots from MAPDL ,'
                               'from Python.  Otherwise, plot with vtk with:\n'
                               '``vtk=True``')
 
+        if not self._png_mode:
+            self.show('PNG')
+            self.gfile(pixel_res)
+
+    @property
+    def _has_matplotlib(self):
+        try:
+            import matplotlib
+            return True
+        except ImportError:
+            return False
+
     @property
     def _png_mode(self):
         """Returns True when MAPDL is set to write plots as png to file."""
@@ -930,7 +927,6 @@ class _MapdlCore(_MapdlCommands):
                                    **kwargs)
 
         # otherwise, use MAPDL plotter
-        self._enable_interactive_plotting()
         return super().eplot()
 
     def lplot(self, nl1="", nl2="", ninc="", vtk=None,
@@ -951,13 +947,9 @@ class _MapdlCore(_MapdlCommands):
         vtk : bool, optional
             Plot the currently selected lines using ``pyvista``.
 
-        show_numbering : bool, optional
+        show_line_numbering : bool, optional
             Display line and keypoint numbers when ``vtk=True``.
 
-        show_keypoints : bool, optional
-            Display keypoints associated with current lines.  Only
-            valid with ``vtk=True``.
-
         show_keypoint_numbering : bool, optional
             Number keypoints.  Only valid when show_keypoints is True
 
@@ -971,8 +963,8 @@ class _MapdlCore(_MapdlCommands):
 
         Notes
         -----
-        Mesh divisions on plotted lines are controlled by the LDIV option of
-        the /PSYMB command.
+        Mesh divisions on plotted lines are controlled by the LDIV
+        option of the /PSYMB command.
 
         This command is valid in any processor.
         """
@@ -1790,8 +1782,6 @@ class _MapdlCore(_MapdlCommands):
         short_cmd = parse_to_short_cmd(command)
 
         # command parsing
-        if short_cmd in geometry_commands:
-            return geometry_commands[short_cmd](self._response)
         if short_cmd in element_commands:
             return element_commands[short_cmd](self._response)
         if short_cmd in PLOT_COMMANDS:
@@ -1815,9 +1805,9 @@ class _MapdlCore(_MapdlCommands):
 
     # @supress_logging
     def load_table(self, name, array, var1='', var2='', var3=''):
-        """Load a table from Python to MAPDL
+        """Load a table from Python to MAPDL.
 
-        Uses \*TREAD to transfer the table.
+        Uses TREAD to transfer the table.
 
         Parameters
         ----------
@@ -1947,7 +1937,9 @@ class _MapdlCore(_MapdlCommands):
 
     def __del__(self):  # pragma: no cover
         """Clean up when complete"""
+        self._log.debug('Collecting...')
         if self._cleanup:
+            self._log.debug('self._cleanup == True')
             try:
                 self.exit()
             except Exception as e:
@@ -2066,6 +2058,9 @@ class _MapdlCore(_MapdlCommands):
 
     def _display_plot(self, text):
         """Display the last generated plot (*.png) from MAPDL"""
+        import scooby
+
+        self._enable_interactive_plotting()
         png_found = PNG_TEST.findall(text)
         if png_found:
             # flush graphics writer
